package # IGNORE ME PAUSE
    My::Test::WithoutViolations;

use strict;
use warnings;

1;

__END__

=pod

=cut
